%global __python %{__python3}
Name:           jgmenu
Version:        4.4.1
Release:        %mkrel 4
Summary:        Small X11 menu intended to be used with openbox and tint2
Group:          Graphical desktop/Other
License:        GPLv2
URL:            https://github.com/johanmalm/jgmenu/wiki
Source0:        https://github.com/johanmalm/jgmenu/archive/v%{version}/%{name}-%{version}.tar.gz

# Add PR to fix registration with Xfce
Patch0:		https://github.com/jgmenu/jgmenu/pull/188.patch

BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libmenu-cache)
BuildRequires:  pkgconfig(xrandr)

%description
- jgmenu is a stand-alone, simple and contemporary-looking menu application
  for Linux and BSD.
- Although it was originally written to be used with openbox and tint2,
  it is not in any way dependent on these and runs well with other panels
  and window managers.
- It is hackable with a clean, small code base.
- It can display the following types of menu (or any combination of):
  o  bespoke menu using a jgmenu flavoured CSV format
  o  application menu (XDG compatible) with localisation support
  o  openbox XML menu including pipe-menus
- It can display SVG, PNG and XPM icons.
- It has UTF-8 search support.
- It is highly customizable (e.g. colours, alignment, margins, padding,
  transparency).
- It can synchronise with xsettings, GTK and tint2 settings.
- It does not depend on any toolkits such as GTK and Qt, but uses cairo and
  pango to render the menu directly onto an X11 window.

%prep
%autosetup -p1

# Fix the path to Python 3
%py3_shebang_fix \
contrib/gtktheme/jgmenu-gtktheme.py \
contrib/mate-panel/mate-jgmenu.py \
contrib/pmenu/jgmenu-pmenu.py \
src/jgmenu-unity-hack.py

%build
%configure
%make_build prefix=%{_prefix} libexecdir=%{_libdir}/%{name}

%install
%make_install prefix=%{_prefix} libexecdir=%{_libdir}/%{name}

%files
%doc README.md TODO.md
%{_bindir}/%{name}*
%{_libdir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/*
%{_mandir}/man7/*
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg


%changelog
* Sun Mar 16 2025 wally <wally> 4.4.1-4.mga10
+ Revision: 2164872
- rebuild for libxml2 2.13.6

* Sun Oct 13 2024 kekepower <kekepower> 4.4.1-3.mga10
+ Revision: 2105880
- Fix build

* Fri Dec 23 2022 kekepower <kekepower> 4.4.1-2.mga9
+ Revision: 1926167
- Add PR to fix xfce4-panel registration
  o See https://github.com/jgmenu/jgmenu/pull/188

* Sun Oct 30 2022 kekepower <kekepower> 4.4.1-1.mga9
+ Revision: 1900285
- Update to version 4.4.1

* Sun Sep 19 2021 kekepower <kekepower> 4.4.0-1.mga9
+ Revision: 1745953
- Update to version 4.4.0

* Tue Mar 02 2021 kekepower <kekepower> 4.3.0-1.mga9
+ Revision: 1696287
- Update to version 4.3.0

* Thu Oct 01 2020 kekepower <kekepower> 4.2.1-1.mga8
+ Revision: 1631408
- Update to version 4.2.1

* Wed May 06 2020 kekepower <kekepower> 4.2.0-1.mga8
+ Revision: 1581363
- Update to version 4.2.0

* Tue Mar 03 2020 kekepower <kekepower> 4.1.0-1.mga8
+ Revision: 1553215
- Update to version 4.1.0

* Thu Feb 20 2020 umeabot <umeabot> 4.0.2-2.mga8
+ Revision: 1546450
- Mageia 8 Mass Rebuild

* Mon Feb 03 2020 kekepower <kekepower> 4.0.2-1.mga8
+ Revision: 1486563
- Update to version 4.0.2

* Mon Jan 20 2020 kekepower <kekepower> 4.0.1-1.mga8
+ Revision: 1481630
- Update to version 4.0.1

* Fri Oct 25 2019 kekepower <kekepower> 3.5-1.mga8
+ Revision: 1455822
- Update to version 3.5

* Sun Oct 20 2019 kekepower <kekepower> 3.4-1.mga8
+ Revision: 1454659
- Update to version 3.4

* Tue Jul 23 2019 kekepower <kekepower> 3.3-1.mga8
+ Revision: 1423484
- Update to version 3.3

* Tue Jul 16 2019 kekepower <kekepower> 3.2-1.mga8
+ Revision: 1421956
- Update to version 3.2

* Mon Jul 08 2019 kekepower <kekepower> 3.1-1.mga8
+ Revision: 1419493
- Update to version 3.1

* Thu Jul 04 2019 kekepower <kekepower> 3.0-1.mga8
+ Revision: 1418179
- Update to version 3.0

* Tue Mar 19 2019 kekepower <kekepower> 2.2.1-1.mga7
+ Revision: 1378990
- Update to version 2.2.1

* Wed Mar 13 2019 kekepower <kekepower> 2.2-1.mga7
+ Revision: 1374998
- Update to version 2.2

* Fri Feb 22 2019 kekepower <kekepower> 2.1-1.mga7
+ Revision: 1369401
- Update to version 2.1
- Rediffed Patch0

* Thu Jan 31 2019 kekepower <kekepower> 2.0-1.mga7
+ Revision: 1362164
- Update to version 2.0

* Fri Dec 28 2018 kekepower <kekepower> 1.6-1.mga7
+ Revision: 1345644
- Update to version 1.6

* Fri Nov 23 2018 kekepower <kekepower> 1.5-1.mga7
+ Revision: 1333670
- Update to version 1.5

* Tue Oct 30 2018 kekepower <kekepower> 1.4.1-1.mga7
+ Revision: 1326577
- Update to version 1.4.1

* Thu Oct 25 2018 kekepower <kekepower> 1.4-1.mga7
+ Revision: 1325251
- Update to version 1.4

* Tue Sep 18 2018 kekepower <kekepower> 1.3-1.mga7
+ Revision: 1263999
- Update to version 1.3

* Sat Aug 25 2018 kekepower <kekepower> 1.2.1-1.mga7
+ Revision: 1254492
- Update to version 1.2.1

* Thu Aug 23 2018 kekepower <kekepower> 1.2-1.mga7
+ Revision: 1253611
- Update to version 1.2
- Update to version 1.1

* Tue Jun 12 2018 kekepower <kekepower> 1.0-1.mga7
+ Revision: 1236628
- Update to version 1.0

* Mon May 28 2018 kekepower <kekepower> 0.9.1-1.mga7
+ Revision: 1232807
- Update to version 0.9.1
- Remove merged upstream patch

* Sat May 26 2018 kekepower <kekepower> 0.9-2.mga7
+ Revision: 1232257
- Add upstream patch for a file read bug

* Mon May 21 2018 kekepower <kekepower> 0.9-1.mga7
+ Revision: 1231282
- imported package jgmenu

